

from django.conf import settings
from django.contrib.auth.models import AbstractUser, BaseUserManager


class UserManager(BaseUserManager):
    def create_user(self, email, password=None, **kwars):
        """
        Creates and saves a User with the given email and password.
        """
        if not email:
            raise ValueError('Users must have an email address')

        user = self.model(
            email=self.normalize_email(email),
        )

        user.set_password(password)
        user.save(using=self._db)
        return user

    def create_superuser(self, email, password):
        """
        Creates and saves a superuser with the given email and password.
        """
        user = self.create_user(
            email, password=password
        )
        user.is_superuser = True
        user.is_staff = True
        user.save(using=self._db)
        return user

if settings.AUTH_USER_MODEL=="gjwt_auth.User":

    class User(AbstractUser):
        USERNAME_FIELD = 'email'
        REQUIRED_FIELDS = []

        objects = UserManager()

        def __str__(self):
            return self.email

    User._meta.get_field('email')._unique = True
    User._meta.get_field('username')._unique = False
